# define variable 'ops': optimisation parameter set
# define variable 'setups': simulation setup set
# define variable 'optimiser': properties for the optimiser

import numpy as np

# Import just for IDE convenience.
import propti as pr


# Input file template for the simulation software.
template_file = "runScript.sh"

# File containing the experimental data that is used as target during the
# inverse modelling process.
exp_data_file = "experimental_data.dat"    

# Character ID used to identify the files connected to one simulation.
CHID = 'simulation_data'  

# Define the optimisation parameters.
op1 = pr.Parameter(name='density',
                   place_holder='rho',
                   min_value=6000, max_value=9000)     
op2 = pr.Parameter(name='youngs_mod',
                   place_holder='E',
                   min_value=1*10**11, max_value=2.5*10**11)

# Collect all the defined parameters from above, just for convenience.
set_of_parameters = [op1, op2]


# Definition of parameters, which is used by `propti_prepare.py` later on.
# It has no further meaning here.
ops = pr.ParameterSet(name="Optimisation parameters",
                      params=set_of_parameters)


# Definition of general model parameters, including optimisation parameters.

mps0 = pr.ParameterSet(name="Environment and\n"
                            "Optimisation parameters",
                       params=set_of_parameters)

# Define model-experiment data relation 
r = pr.Relation()
r.model.file_name = "{}.dat".format(CHID)       # Simulation output file name
r.model.label_x = 'Time'
r.model.label_y = 'max(D)'                 
r.model.header_line = 1                 
r.experiment.file_name = exp_data_file  
r.experiment.label_x = 'Time'
r.experiment.label_y = 'max(D)'
r.experiment.header_line = 0

# Define definition range for data comparison
r.x_def = np.arange(1., 5001, 1)  

# Create simulation setup object
s = pr.SimulationSetup(name='analysis_01',
                       work_dir='workdir',
                       model_template=template_file,
                       model_input_file=template_file,      # NOT SURE ABOUT THIS
                       model_parameter=mps0,
                       model_executable='/bin/sh',
                       relations=r)         
 
# Define empty simulation setup set
setups = pr.SimulationSetupSet()
# Append above object to simulation setup set
setups.append(s)

# Provide parameter values for the optimiser, some of the default values are
# highlighted here.
optimiser = pr.OptimiserProperties(algorithm='sceua',
                                   repetitions=400,
                                   ngs=len(set_of_parameters),
                                   backup_every=100,
                                   db_name='propti_db',
                                   db_type='csv',
                                   db_precision=np.float64,
                                   mpi=False)


print('** input file processed')
